@@ -24,6 +24,8 @@
 #include <libintl.h>
 #endif
 
+#include <xfconf/xfconf.h>
+
 
 /* globals */
 static gchar    **filenames = NULL;
@@ -55,9 +57,6 @@ main (gint argc, gchar **argv)
   MousepadApplication *application;
   GError              *error = NULL;
   gchar               *working_directory;
-#ifdef HAVE_DBUS
-  MousepadDBusService *dbus_service;
-#endif
 
   /* bind the text domain to the locale directory */
   bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
@@ -87,12 +86,12 @@ main (gint argc, gchar **argv)
       if (G_LIKELY (error == NULL))
         {
           /* no error message, the gui initialization failed */
-          g_error ("%s", _("Failed to open display."));
+          g_printerr ("%s\n", _("Failed to open display."));
         }
       else
         {
           /* print the error message */
-          g_error ("%s", error->message);
+          g_printerr ("%s\n", error->message);
           g_error_free (error);
         }
 
@@ -118,7 +117,7 @@ main (gint argc, gchar **argv)
       /* try to terminate whatever is running */
       if (!mousepad_dbus_client_terminate (&error))
         {
-          g_error ("Failed to terminate a running instance: %s\n", error->message);
+          g_printerr ("Failed to terminate a running instance: %s\n", error->message);
           g_error_free (error);
           return EXIT_FAILURE;
         }
@@ -146,7 +145,7 @@ main (gint argc, gchar **argv)
           /* print errors, if needed */
           if (G_UNLIKELY (error))
             {
-              g_error ("Mousepad: %s\n", error->message);
+              g_printerr ("Mousepad: %s\n", error->message);
               g_error_free (error);
 
               return EXIT_FAILURE;
@@ -154,12 +153,28 @@ main (gint argc, gchar **argv)
 
           return EXIT_SUCCESS;
         }
+
+        /* No instance may own the service name, so we need to clean the error */
+        if (G_UNLIKELY (error))
+          {
+            g_error_free (error);
+            error = NULL;
+          }
     }
 #endif /* !HAVE_DBUS */
 
   /* use the Mousepad icon as default for new windows */
   gtk_window_set_default_icon_name ("accessories-text-editor");
 
+  /* Initialize xfconf */
+  if (G_UNLIKELY (xfconf_init(&error) == FALSE))
+    {
+      g_printerr ("Failed to initialize xfconf");
+      g_error_free (error);
+
+      return EXIT_FAILURE;
+    }
+
   /* create a new mousepad application */
   application = mousepad_application_get ();
 
@@ -175,16 +190,14 @@ main (gint argc, gchar **argv)
     {
 #ifdef HAVE_DBUS
       /* register with dbus */
-      dbus_service = g_object_new (MOUSEPAD_TYPE_DBUS_SERVICE, NULL);
+      mousepad_dbus_service_init ();
 #endif
 
       /* enter the main loop */
       gtk_main ();
 
-#ifdef HAVE_DBUS
-      /* release dbus service reference */
-      g_object_unref (G_OBJECT (dbus_service));
-#endif
+      /* Shutdown xfconf */
+      xfconf_shutdown();
     }
 
   /* release application reference */
