@@ -14,31 +14,27 @@
  * Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#include <mousepad/mousepad-private.h>
+#include <mousepad/mousepad-gtkcompat.h>
+#include <mousepad/mousepad-close-button.h>
+#include <mousepad/mousepad-settings.h>
+#include <mousepad/mousepad-util.h>
+#include <mousepad/mousepad-document.h>
+#include <mousepad/mousepad-marshal.h>
+#include <mousepad/mousepad-view.h>
+#include <mousepad/mousepad-window.h>
+
+#if GTK_CHECK_VERSION(3, 0, 0)
+#include <gtksourceview/gtksource.h>
+#else
+#include <gtksourceview/gtksourcebuffer.h>
 #endif
 
 #ifdef HAVE_MEMORY_H
 #include <memory.h>
 #endif
-#ifdef HAVE_STRING_H
-#include <string.h>
-#endif
-#ifdef HAVE_TIME_H
+
 #include <time.h>
-#endif
-
-#include <mousepad/mousepad-private.h>
-#include <mousepad/mousepad-util.h>
-#include <mousepad/mousepad-document.h>
-#include <mousepad/mousepad-marshal.h>
-#include <mousepad/mousepad-view.h>
-#include <mousepad/mousepad-preferences.h>
-#include <mousepad/mousepad-window.h>
-
-
-
-#define MOUSEPAD_DOCUMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), MOUSEPAD_TYPE_DOCUMENT, MousepadDocumentPrivate))
 
 
 
@@ -96,9 +92,6 @@ struct _MousepadDocumentPrivate
   /* utf-8 valid document names */
   gchar               *utf8_filename;
   gchar               *utf8_basename;
-
-  /* settings */
-  guint                word_wrap : 1;
 };
 
 
@@ -115,7 +108,7 @@ mousepad_document_new (void)
 
 
 
-G_DEFINE_TYPE (MousepadDocument, mousepad_document, GTK_TYPE_SCROLLED_WINDOW);
+G_DEFINE_TYPE_WITH_PRIVATE (MousepadDocument, mousepad_document, GTK_TYPE_SCROLLED_WINDOW)
 
 
 
@@ -124,8 +117,6 @@ mousepad_document_class_init (MousepadDocumentClass *klass)
 {
   GObjectClass *gobject_class;
 
-  g_type_class_add_private (klass, sizeof (MousepadDocumentPrivate));
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = mousepad_document_finalize;
 
@@ -167,7 +158,7 @@ mousepad_document_class_init (MousepadDocumentClass *klass)
                   G_SIGNAL_RUN_LAST,
                   0, NULL, NULL,
                   g_cclosure_marshal_VOID__OBJECT,
-                  G_TYPE_NONE, 1, GTK_TYPE_SOURCE_LANGUAGE);
+                  G_TYPE_NONE, 1, GTK_SOURCE_TYPE_LANGUAGE);
 }
 
 
@@ -176,14 +167,9 @@ static void
 mousepad_document_init (MousepadDocument *document)
 {
   GtkTargetList        *target_list;
-  gboolean              word_wrap, auto_indent, line_numbers, insert_spaces;
-  gchar                *font_name, *color_scheme;
-  gint                  tab_size;
-  GtkSourceStyleScheme *scheme = NULL;
-  MousepadPreferences  *preferences;
 
   /* private structure */
-  document->priv = MOUSEPAD_DOCUMENT_GET_PRIVATE (document);
+  document->priv = mousepad_document_get_instance_private (document);
 
   /* initialize the variables */
   document->priv->utf8_filename = NULL;
@@ -217,40 +203,6 @@ mousepad_document_init (MousepadDocument *document)
   target_list = gtk_drag_dest_get_target_list (GTK_WIDGET (document->textview));
   gtk_target_list_add_table (target_list, drop_targets, G_N_ELEMENTS (drop_targets));
 
-  /* preferences */
-  preferences = mousepad_preferences_get ();
-
-  /* read all the default settings */
-  g_object_get (G_OBJECT (preferences),
-                "view-word-wrap", &word_wrap,
-                "view-line-numbers", &line_numbers,
-                "view-auto-indent", &auto_indent,
-                "view-font-name", &font_name,
-                "view-tab-size", &tab_size,
-                "view-insert-spaces", &insert_spaces,
-                "view-color-scheme", &color_scheme,
-                NULL);
-
-  /* release the preferences */
-  g_object_unref (G_OBJECT (preferences));
-
-  /* set all the settings */
-  mousepad_document_set_word_wrap (document, word_wrap);
-  mousepad_document_set_font (document, font_name);
-  mousepad_view_set_line_numbers (document->textview, line_numbers);
-  mousepad_view_set_auto_indent (document->textview, auto_indent);
-  mousepad_view_set_tab_size (document->textview, tab_size);
-  mousepad_view_set_insert_spaces (document->textview, insert_spaces);
-
-  if (g_strcmp0 (color_scheme, "none") != 0)
-    scheme =  gtk_source_style_scheme_manager_get_scheme (gtk_source_style_scheme_manager_get_default (), color_scheme);
-  gtk_source_buffer_set_highlight_syntax (GTK_SOURCE_BUFFER (document->buffer), (scheme != NULL));
-  gtk_source_buffer_set_style_scheme (GTK_SOURCE_BUFFER (document->buffer), scheme);
-
-  /* cleanup */
-  g_free (font_name);
-  g_free (color_scheme);
-
   /* attach signals to the text view and buffer */
   g_signal_connect (G_OBJECT (document->buffer), "notify::cursor-position", G_CALLBACK (mousepad_document_notify_cursor_position), document);
   g_signal_connect (G_OBJECT (document->buffer), "notify::has-selection", G_CALLBACK (mousepad_document_notify_has_selection), document);
@@ -292,8 +244,8 @@ mousepad_document_notify_cursor_position (GtkTextBuffer    *buffer,
   gint        line, column, selection;
   gint        tab_size;
 
-  mousepad_return_if_fail (GTK_IS_TEXT_BUFFER (buffer));
-  mousepad_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
+  g_return_if_fail (GTK_IS_TEXT_BUFFER (buffer));
+  g_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
 
   /* get the current iter position */
   gtk_text_buffer_get_iter_at_mark (buffer, &iter, gtk_text_buffer_get_insert (buffer));
@@ -302,7 +254,7 @@ mousepad_document_notify_cursor_position (GtkTextBuffer    *buffer,
   line = gtk_text_iter_get_line (&iter) + 1;
 
   /* get the tab size */
-  tab_size = mousepad_view_get_tab_size (document->textview);
+  tab_size = MOUSEPAD_SETTING_GET_INT (TAB_WIDTH);
 
   /* get the column */
   column = mousepad_util_get_real_line_offset (&iter, tab_size);
@@ -324,8 +276,8 @@ mousepad_document_notify_has_selection (GtkTextBuffer    *buffer,
   gint     selection;
   gboolean is_column_selection;
 
-  mousepad_return_if_fail (GTK_IS_TEXT_BUFFER (buffer));
-  mousepad_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
+  g_return_if_fail (GTK_IS_TEXT_BUFFER (buffer));
+  g_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
 
   /* get length of the selection */
   selection = mousepad_view_get_selection_length (document->textview, &is_column_selection);
@@ -351,8 +303,8 @@ mousepad_document_notify_overwrite (GtkTextView      *textview,
 {
   gboolean overwrite;
 
-  mousepad_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
-  mousepad_return_if_fail (GTK_IS_TEXT_VIEW (textview));
+  g_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
+  g_return_if_fail (GTK_IS_TEXT_VIEW (textview));
 
   /* whether overwrite is enabled */
   overwrite = gtk_text_view_get_overwrite (textview);
@@ -370,8 +322,8 @@ mousepad_document_notify_language (GtkSourceBuffer  *buffer,
 {
   GtkSourceLanguage *language;
 
-  mousepad_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
-  mousepad_return_if_fail (GTK_IS_SOURCE_BUFFER (buffer));
+  g_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
+  g_return_if_fail (GTK_SOURCE_IS_BUFFER (buffer));
 
   /* the new language */
   language = gtk_source_buffer_get_language (buffer);
@@ -392,7 +344,7 @@ mousepad_document_drag_data_received (GtkWidget        *widget,
                                       guint             drag_time,
                                       MousepadDocument *document)
 {
-  mousepad_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
+  g_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
 
   /* emit the drag-data-received signal from the document when a tab or uri has been dropped */
   if (info == TARGET_TEXT_URI_LIST || info == TARGET_GTK_NOTEBOOK_TAB)
@@ -407,8 +359,8 @@ mousepad_document_filename_changed (MousepadDocument *document,
 {
   gchar *utf8_filename, *utf8_basename;
 
-  mousepad_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
-  mousepad_return_if_fail (filename != NULL);
+  g_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
+  g_return_if_fail (filename != NULL);
 
   /* convert the title into a utf-8 valid version for display */
   utf8_filename = g_filename_to_utf8 (filename, -1, NULL, NULL, NULL);
@@ -433,7 +385,7 @@ mousepad_document_filename_changed (MousepadDocument *document,
           gtk_label_set_text (GTK_LABEL (document->priv->label), utf8_basename);
 
           /* set the tab tooltip */
-          mousepad_widget_set_tooltip_text (document->priv->ebox, utf8_filename);
+          gtk_widget_set_tooltip_text (document->priv->ebox, utf8_filename);
 
           /* update label color */
           mousepad_document_label_color (document);
@@ -450,9 +402,9 @@ mousepad_document_label_color (MousepadDocument *document)
   GdkColor  red   = {0, 0xffff, 0x0000, 0x0000};
   GdkColor *color;
 
-  mousepad_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
-  mousepad_return_if_fail (GTK_IS_TEXT_BUFFER (document->buffer));
-  mousepad_return_if_fail (MOUSEPAD_IS_FILE (document->file));
+  g_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
+  g_return_if_fail (GTK_IS_TEXT_BUFFER (document->buffer));
+  g_return_if_fail (MOUSEPAD_IS_FILE (document->file));
 
   if (document->priv->label)
     {
@@ -476,52 +428,17 @@ void
 mousepad_document_set_overwrite (MousepadDocument *document,
                                  gboolean          overwrite)
 {
-  mousepad_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
+  g_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
 
   gtk_text_view_set_overwrite (GTK_TEXT_VIEW (document->textview), overwrite);
 }
 
 
 
-void
-mousepad_document_set_word_wrap (MousepadDocument *document,
-                                 gboolean          word_wrap)
-{
-  mousepad_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
-
-  /* store the setting */
-  document->priv->word_wrap = word_wrap;
-
-  /* set the wrapping mode */
-  gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (document->textview),
-                               word_wrap ? GTK_WRAP_WORD : GTK_WRAP_NONE);
-}
-
-
-
-void
-mousepad_document_set_font (MousepadDocument *document,
-                            const gchar      *font_name)
-{
-  PangoFontDescription *font_desc;
-
-  mousepad_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
-
-  if (G_LIKELY (font_name))
-    {
-      /* set the widget font */
-      font_desc = pango_font_description_from_string (font_name);
-      gtk_widget_modify_font (GTK_WIDGET (document->textview), font_desc);
-      pango_font_description_free (font_desc);
-    }
-}
-
-
-
 void
 mousepad_document_focus_textview (MousepadDocument *document)
 {
-  mousepad_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
+  g_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
 
   /* focus the textview */
   gtk_widget_grab_focus (GTK_WIDGET (document->textview));
@@ -532,7 +449,7 @@ mousepad_document_focus_textview (MousepadDocument *document)
 void
 mousepad_document_send_signals (MousepadDocument *document)
 {
-  mousepad_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
+  g_return_if_fail (MOUSEPAD_IS_DOCUMENT (document));
 
   /* re-send the cursor changed signal */
   mousepad_document_notify_cursor_position (document->buffer, NULL, document);
@@ -552,18 +469,17 @@ mousepad_document_send_signals (MousepadDocument *document)
 GtkWidget *
 mousepad_document_get_tab_label (MousepadDocument *document)
 {
-  GtkWidget  *hbox;
-  GtkWidget  *button, *image;
-  GtkRcStyle *style;
+  GtkWidget  *hbox, *align;
+  GtkWidget  *button;
 
   /* create the box */
-  hbox = gtk_hbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_widget_show (hbox);
 
   /* the ebox */
   document->priv->ebox = g_object_new (GTK_TYPE_EVENT_BOX, "border-width", 2, "visible-window", FALSE, NULL);
   gtk_box_pack_start (GTK_BOX (hbox), document->priv->ebox, TRUE, TRUE, 0);
-  mousepad_widget_set_tooltip_text (document->priv->ebox, document->priv->utf8_filename);
+  gtk_widget_set_tooltip_text (document->priv->ebox, document->priv->utf8_filename);
   gtk_widget_show (document->priv->ebox);
 
   /* create the label */
@@ -575,28 +491,16 @@ mousepad_document_get_tab_label (MousepadDocument *document)
   mousepad_document_label_color (document);
 
   /* create the button */
-  button = gtk_button_new ();
-  gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
-  gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
-  gtk_widget_set_can_default(GTK_WIDGET(button), FALSE);
-  gtk_widget_set_can_focus(GTK_WIDGET(button), FALSE);
-
-  /* make button a bit smaller */
-  style = gtk_rc_style_new ();
-  style->xthickness = style->ythickness = 0;
-  gtk_widget_modify_style (button, style);
-  g_object_unref (G_OBJECT (style));
-
-  /* pack button, add signal and tooltip */
-  mousepad_widget_set_tooltip_text (button, _("Close this tab"));
-  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
-  g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (mousepad_document_tab_button_clicked), document);
+  align = gtk_alignment_new (1.0, 0.5, 0.0, 0.0);
+  button = mousepad_close_button_new ();
+  gtk_container_add (GTK_CONTAINER (align), button);
   gtk_widget_show (button);
 
-  /* button image */
-  image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
-  gtk_container_add (GTK_CONTAINER (button), image);
-  gtk_widget_show (image);
+  /* pack button, add signal and tooltip */
+  gtk_widget_set_tooltip_text (button, _("Close this tab"));
+  gtk_box_pack_start (GTK_BOX (hbox), align, FALSE, FALSE, 0);
+  g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (mousepad_document_tab_button_clicked), document);
+  gtk_widget_show (align);
 
   return hbox;
 }
@@ -617,7 +521,7 @@ mousepad_document_get_basename (MousepadDocument *document)
 {
   static gint untitled_counter = 0;
 
-  mousepad_return_val_if_fail (MOUSEPAD_IS_DOCUMENT (document), NULL);
+  g_return_val_if_fail (MOUSEPAD_IS_DOCUMENT (document), NULL);
 
   /* check if there is a filename set */
   if (document->priv->utf8_basename == NULL)
@@ -634,17 +538,7 @@ mousepad_document_get_basename (MousepadDocument *document)
 const gchar *
 mousepad_document_get_filename (MousepadDocument *document)
 {
-  mousepad_return_val_if_fail (MOUSEPAD_IS_DOCUMENT (document), NULL);
+  g_return_val_if_fail (MOUSEPAD_IS_DOCUMENT (document), NULL);
 
   return document->priv->utf8_filename;
 }
-
-
-
-gboolean
-mousepad_document_get_word_wrap (MousepadDocument *document)
-{
-  mousepad_return_val_if_fail (MOUSEPAD_IS_DOCUMENT (document), FALSE);
-
-  return document->priv->word_wrap;
-}
