@@ -14,16 +14,6 @@
  * Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#ifdef HAVE_STRING_H
-#include <string.h>
-#endif
-
-#include <glib.h>
-
 #include <mousepad/mousepad-private.h>
 #include <mousepad/mousepad-encoding.h>
 
