@@ -19,9 +19,14 @@
 #include <mousepad/mousepad-file.h>
 
 #include <glib/gstdio.h>
+
+#if GTK_CHECK_VERSION(3, 0, 0)
+#include <gtksourceview/gtksource.h>
+#else
 #include <gtksourceview/gtksourcebuffer.h>
 #include <gtksourceview/gtksourcelanguage.h>
 #include <gtksourceview/gtksourcelanguagemanager.h>
+#endif
 
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -280,6 +285,10 @@ mousepad_file_set_filename (MousepadFile *file,
 {
   g_return_if_fail (MOUSEPAD_IS_FILE (file));
 
+  /* reset the stored modification time when a new filename set */
+  if (g_strcmp0 (file->filename, filename) != 0)
+    file->mtime = 0;
+
   /* free the old filename */
   g_free (file->filename);
 
@@ -450,23 +459,19 @@ GtkSourceLanguage *
 mousepad_file_guess_language (MousepadFile *file)
 {
   gchar             *content_type;
+  gchar             *basename;
   gboolean           result_uncertain;
-  GtkSourceLanguage *language = NULL;
+  GtkSourceLanguage *language;
+
+  g_return_val_if_fail ((file->filename != NULL), NULL);
 
   content_type = g_content_type_guess (file->filename, NULL, 0, &result_uncertain);
-  if (result_uncertain)
-    {
-      g_free (content_type);
-      content_type = NULL;
-    }
-
-  if (G_LIKELY (content_type != NULL || file->filename != NULL))
-    {
-      language = gtk_source_language_manager_guess_language (gtk_source_language_manager_get_default (),
-                                                             file->filename,
-                                                             content_type);
-    }
+  basename = g_path_get_basename (file->filename);
+  language = gtk_source_language_manager_guess_language (gtk_source_language_manager_get_default (),
+                                                         basename,
+                                                         result_uncertain ? NULL : content_type);
 
+  g_free (basename);
   g_free (content_type);
 
   return language;
@@ -603,6 +608,11 @@ mousepad_file_open (MousepadFile  *file,
                 }
             }
 
+          /* text view doesn't expect a line ending at end of last line, but Unix and Mac files do */
+          if ((n = g_utf8_find_prev_char(contents, end)) && (*n == '\r' ||
+              (*n == '\n' && (!(n = g_utf8_find_prev_char(contents, n)) || *n != '\r'))))
+            end--;
+
           /* get the iter at the beginning of the document */
           gtk_text_buffer_get_start_iter (file->buffer, &start_iter);
 
@@ -681,8 +691,11 @@ mousepad_file_open (MousepadFile  *file,
       g_mapped_file_free (mapped_file);
 #endif
 
-      /* guess and set the file's filetype/language */
-      mousepad_file_set_language (file, mousepad_file_guess_language (file));
+      if (G_LIKELY (filename != template_filename))
+        {
+          /* guess and set the file's filetype/language */
+          mousepad_file_set_language (file, mousepad_file_guess_language (file));
+        }
 
       /* this does not count as a modified buffer */
       gtk_text_buffer_set_modified (file->buffer, FALSE);
@@ -757,8 +770,8 @@ mousepad_file_save (MousepadFile  *file,
           /* add and utf-8 bom at the start of the contents if needed */
           if (file->write_bom && mousepad_encoding_is_unicode (file->encoding))
             {
-              /* realloc the contents string */
-              contents = g_realloc (contents, length + 4);
+              /* realloc the contents string. +1 in case we append extra line ending */
+              contents = g_realloc (contents, length + 5);
 
               /* move the existing contents 3 bytes */
               g_memmove (contents + 3, contents, length + 1);
@@ -772,6 +785,18 @@ mousepad_file_save (MousepadFile  *file,
               length += 3;
             }
 
+          /* text view doesn't expect a line ending at end of last line, but Unix and Mac files do */
+          if (file->line_ending != MOUSEPAD_EOL_DOS && 0 < length)
+            {
+              /* realloc contents. does nothing if realloc above already resized */
+              contents = g_realloc (contents, length + 2);
+
+              contents[length] = file->line_ending == MOUSEPAD_EOL_MAC ? '\r' : '\n';
+              contents[length + 1] = '\0';
+
+              length++;
+            }
+
           /* convert to the encoding if set */
           if (G_UNLIKELY (file->encoding != MOUSEPAD_ENCODING_UTF_8))
             {
