@@ -21,7 +21,11 @@ G_BEGIN_DECLS
 
 #include <mousepad/mousepad-encoding.h>
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+#include <gtksourceview/gtksource.h>
+#else
 #include <gtksourceview/gtksourcelanguage.h>
+#endif
 
 typedef struct _MousepadFileClass  MousepadFileClass;
 typedef struct _MousepadFile       MousepadFile;
