@@ -14,21 +14,17 @@
  * Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <gdk/gdk.h>
-#include <gdk/gdkkeysyms.h>
-
 #include <mousepad/mousepad-private.h>
+#include <mousepad/mousepad-gtkcompat.h>
+#include <mousepad/mousepad-settings.h>
 #include <mousepad/mousepad-marshal.h>
 #include <mousepad/mousepad-document.h>
 #include <mousepad/mousepad-search-bar.h>
-#include <mousepad/mousepad-preferences.h>
 #include <mousepad/mousepad-util.h>
 #include <mousepad/mousepad-window.h>
 
+#include <gdk/gdk.h>
+
 
 
 #define TOOL_BAR_ICON_SIZE  GTK_ICON_SIZE_MENU
@@ -40,14 +36,16 @@ static void      mousepad_search_bar_finalize                   (GObject
 static void      mousepad_search_bar_find_string                (MousepadSearchBar       *bar,
                                                                  MousepadSearchFlags   flags);
 static void      mousepad_search_bar_hide_clicked               (MousepadSearchBar       *bar);
+static void      mousepad_search_bar_entry_activate             (GtkWidget               *entry,
+                                                                 MousepadSearchBar       *bar);
+static void      mousepad_search_bar_entry_activate_backward    (GtkWidget               *entry,
+                                                                 MousepadSearchBar       *bar);
 static void      mousepad_search_bar_entry_changed              (GtkWidget               *entry,
                                                                  MousepadSearchBar       *bar);
 static void      mousepad_search_bar_highlight_toggled          (GtkWidget               *button,
                                                                  MousepadSearchBar       *bar);
 static void      mousepad_search_bar_match_case_toggled         (GtkWidget               *button,
                                                                  MousepadSearchBar       *bar);
-static void      mousepad_search_bar_menuitem_toggled           (GtkCheckMenuItem        *item,
-                                                                 GtkToggleButton         *button);
 static void      mousepad_search_bar_highlight_schedule         (MousepadSearchBar       *bar);
 static gboolean  mousepad_search_bar_highlight_timeout          (gpointer                 user_data);
 static void      mousepad_search_bar_highlight_timeout_destroy  (gpointer                 user_data);
@@ -70,9 +68,6 @@ struct _MousepadSearchBar
 {
   GtkToolbar           __parent__;
 
-  /* preferences */
-  MousepadPreferences *preferences;
-
   /* text entry */
   GtkWidget           *entry;
 
@@ -104,7 +99,7 @@ mousepad_search_bar_new (void)
 
 
 
-G_DEFINE_TYPE (MousepadSearchBar, mousepad_search_bar, GTK_TYPE_TOOLBAR);
+G_DEFINE_TYPE (MousepadSearchBar, mousepad_search_bar, GTK_TYPE_TOOLBAR)
 
 
 
@@ -112,6 +107,7 @@ static void
 mousepad_search_bar_class_init (MousepadSearchBarClass *klass)
 {
   GObjectClass  *gobject_class;
+  GObjectClass  *entry_class;
   GtkBindingSet *binding_set;
 
   gobject_class = G_OBJECT_CLASS (klass);
@@ -140,6 +136,12 @@ mousepad_search_bar_class_init (MousepadSearchBarClass *klass)
   binding_set = gtk_binding_set_by_class (klass);
   gtk_binding_entry_add_signal (binding_set, GDK_Escape, 0, "hide-bar", 0);
 
+  /* In GTK3, gtkrc is deprecated */
+#if GTK_CHECK_VERSION(3, 0, 0) && (__GNUC__ > 4 || __GNUC__ == 4 && __GNUC_MINOR__ > 2)
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+
   /* hide the shadow around the toolbar */
   gtk_rc_parse_string ("style \"mousepad-search-bar-style\"\n"
                          "{\n"
@@ -153,6 +155,27 @@ mousepad_search_bar_class_init (MousepadSearchBarClass *klass)
                            "GtkToolButton::icon-spacing = 2\n"
                          "}\n"
                        "widget \"MousepadWindow.*.Gtk*ToolButton\" style \"mousepad-button-style\"\n");
+
+#if GTK_CHECK_VERSION(3, 0, 0) && (__GNUC__ > 4 || __GNUC__ == 4 && __GNUC_MINOR__ > 2)
+# pragma GCC diagnostic pop
+#endif
+
+  /* add an activate-backwards signal to GtkEntry */
+  entry_class = g_type_class_ref (GTK_TYPE_ENTRY);
+  if (G_LIKELY (g_signal_lookup("activate-backward", GTK_TYPE_ENTRY) == 0))
+    {
+      /* install the signal */
+      g_signal_new("activate-backward",
+                   GTK_TYPE_ENTRY,
+                   G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+                   0, NULL, NULL,
+                   g_cclosure_marshal_VOID__VOID,
+                   G_TYPE_NONE, 0);
+      binding_set = gtk_binding_set_by_class(entry_class);
+      gtk_binding_entry_add_signal(binding_set, GDK_Return, GDK_SHIFT_MASK, "activate-backward", 0);
+      gtk_binding_entry_add_signal(binding_set, GDK_KP_Enter, GDK_SHIFT_MASK, "activate-backward", 0);
+    }
+  g_type_class_unref (entry_class);
 }
 
 
@@ -164,11 +187,8 @@ mousepad_search_bar_init (MousepadSearchBar *bar)
   GtkToolItem *item;
   gboolean     match_case;
 
-  /* preferences */
-  bar->preferences = mousepad_preferences_get ();
-
-  /* load some preferences */
-  g_object_get (G_OBJECT (bar->preferences), "search-match-case", &match_case, NULL);
+  /* load some saved state */
+  match_case = MOUSEPAD_SETTING_GET_BOOLEAN (SEARCH_MATCH_CASE);
 
   /* init variables */
   bar->highlight_id = 0;
@@ -199,6 +219,8 @@ mousepad_search_bar_init (MousepadSearchBar *bar)
   gtk_container_add (GTK_CONTAINER (item), bar->entry);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), bar->entry);
   g_signal_connect (G_OBJECT (bar->entry), "changed", G_CALLBACK (mousepad_search_bar_entry_changed), bar);
+  g_signal_connect (G_OBJECT (bar->entry), "activate", G_CALLBACK (mousepad_search_bar_entry_activate), bar);
+  g_signal_connect (G_OBJECT (bar->entry), "activate-backward", G_CALLBACK (mousepad_search_bar_entry_activate_backward), bar);
   gtk_widget_show (bar->entry);
 
   /* next button */
@@ -247,11 +269,15 @@ mousepad_search_bar_init (MousepadSearchBar *bar)
   g_signal_connect (G_OBJECT (check), "toggled", G_CALLBACK (mousepad_search_bar_match_case_toggled), bar);
   gtk_widget_show (check);
 
+  /* keep the widgets in sync with the GSettings */
+  MOUSEPAD_SETTING_BIND (SEARCH_MATCH_CASE, check, "active", G_SETTINGS_BIND_DEFAULT);
+
+  /* overflow menu item for when window is too narrow to show the tool bar item */
   bar->match_case_entry = menuitem = gtk_check_menu_item_new_with_mnemonic (_("Mat_ch Case"));
   g_signal_connect_object (G_OBJECT (bar), "destroy", G_CALLBACK (gtk_widget_destroy), item, G_CONNECT_SWAPPED);
   gtk_tool_item_set_proxy_menu_item (item, "case-sensitive", menuitem);
-  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem), match_case);
-  g_signal_connect (G_OBJECT (menuitem), "toggled", G_CALLBACK (mousepad_search_bar_menuitem_toggled), check);
+  /* Keep toolbar check button and overflow proxy menu item in sync */
+  g_object_bind_property (check, "active", menuitem, "active", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
   gtk_widget_show (menuitem);
 }
 
@@ -262,9 +288,6 @@ mousepad_search_bar_finalize (GObject *object)
 {
   MousepadSearchBar *bar = MOUSEPAD_SEARCH_BAR (object);
 
-  /* release the preferences */
-  g_object_unref (G_OBJECT (bar->preferences));
-
   /* stop a running highlight timeout */
   if (bar->highlight_id != 0)
     g_source_remove (bar->highlight_id);
@@ -316,7 +339,7 @@ mousepad_search_bar_find_string (MousepadSearchBar   *bar,
 static void
 mousepad_search_bar_hide_clicked (MousepadSearchBar *bar)
 {
-  mousepad_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
+  g_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
 
   /* emit the signal */
   g_signal_emit (G_OBJECT (bar), search_bar_signals[HIDE_BAR], 0);
@@ -324,6 +347,24 @@ mousepad_search_bar_hide_clicked (MousepadSearchBar *bar)
 
 
 
+static void
+mousepad_search_bar_entry_activate (GtkWidget         *entry,
+                                    MousepadSearchBar *bar)
+{
+  mousepad_search_bar_find_next (bar);
+}
+
+
+
+static void
+mousepad_search_bar_entry_activate_backward (GtkWidget         *entry,
+                                             MousepadSearchBar *bar)
+{
+  mousepad_search_bar_find_previous (bar);
+}
+
+
+
 static void
 mousepad_search_bar_entry_changed (GtkWidget         *entry,
                                    MousepadSearchBar *bar)
@@ -349,7 +390,7 @@ mousepad_search_bar_highlight_toggled (GtkWidget         *button,
 {
   MousepadSearchFlags flags;
 
-  mousepad_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
+  g_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
 
   /* set the new state */
   bar->highlight_all = gtk_toggle_tool_button_get_active (GTK_TOGGLE_TOOL_BUTTON (button));
@@ -382,20 +423,14 @@ mousepad_search_bar_match_case_toggled (GtkWidget         *button,
 {
   gboolean active;
 
-  mousepad_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
+  g_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
 
   /* get the state of the toggle button */
   active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 
-  /* set the state of the menu item */
-  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (bar->match_case_entry), active);
-
   /* save the state */
   bar->match_case = active;
 
-  /* save the setting */
-  g_object_set (G_OBJECT (bar->preferences), "search-match-case", active, NULL);
-
   /* search ahead with this new flags */
   mousepad_search_bar_entry_changed (NULL, bar);
 
@@ -405,26 +440,10 @@ mousepad_search_bar_match_case_toggled (GtkWidget         *button,
 
 
 
-static void
-mousepad_search_bar_menuitem_toggled (GtkCheckMenuItem *item,
-                                      GtkToggleButton  *button)
-{
-  gboolean active;
-
-  mousepad_return_if_fail (GTK_IS_CHECK_MENU_ITEM (item));
-  mousepad_return_if_fail (GTK_IS_TOGGLE_BUTTON (button));
-
-  /* toggle the menubar item, he/she will send the signal */
-  active = gtk_check_menu_item_get_active (item);
-  gtk_toggle_button_set_active (button, active);
-}
-
-
-
 static void
 mousepad_search_bar_highlight_schedule (MousepadSearchBar *bar)
 {
-  mousepad_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
+  g_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
 
   /* stop a pending timeout */
   if (bar->highlight_id != 0)
@@ -454,8 +473,6 @@ mousepad_search_bar_highlight_timeout (gpointer user_data)
   MousepadSearchBar   *bar = MOUSEPAD_SEARCH_BAR (user_data);
   MousepadSearchFlags  flags;
 
-  GDK_THREADS_ENTER ();
-
   /* set search flags */
   flags = MOUSEPAD_SEARCH_FLAGS_DIR_FORWARD
           | MOUSEPAD_SEARCH_FLAGS_ITER_AREA_START
@@ -464,8 +481,6 @@ mousepad_search_bar_highlight_timeout (gpointer user_data)
   /* emit signal */
   mousepad_search_bar_find_string (bar, flags);
 
-  GDK_THREADS_LEAVE ();
-
   /* stop the timeout */
   return FALSE;
 }
@@ -486,7 +501,7 @@ mousepad_search_bar_entry (MousepadSearchBar *bar)
 void
 mousepad_search_bar_focus (MousepadSearchBar *bar)
 {
-  mousepad_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
+  g_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
 
   /* focus the entry field */
   gtk_widget_grab_focus (bar->entry);
@@ -508,7 +523,7 @@ mousepad_search_bar_find_next (MousepadSearchBar *bar)
 {
   MousepadSearchFlags flags;
 
-  mousepad_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
+  g_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
 
   /* set search flags */
   flags = MOUSEPAD_SEARCH_FLAGS_ITER_SEL_END
@@ -525,7 +540,7 @@ mousepad_search_bar_find_previous (MousepadSearchBar *bar)
 {
   MousepadSearchFlags flags;
 
-  mousepad_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
+  g_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
 
   /* set search flags */
   flags = MOUSEPAD_SEARCH_FLAGS_ITER_SEL_START
@@ -534,3 +549,13 @@ mousepad_search_bar_find_previous (MousepadSearchBar *bar)
   /* search */
   mousepad_search_bar_find_string (bar, flags);
 }
+
+
+
+void
+mousepad_search_bar_set_text (MousepadSearchBar *bar, gchar *text)
+{
+  g_return_if_fail (MOUSEPAD_IS_SEARCH_BAR (bar));
+
+  gtk_entry_set_text (GTK_ENTRY (bar->entry), text);
+}
