@@ -806,8 +806,6 @@ mousepad_util_search_get_iters (GtkTextBuffer       *buffer,
       tmp = *start;
       *start = *end;
       *end = tmp;
-      /* when searching backwards, we need to start before the selection */
-      gtk_text_iter_backward_char (iter);
     }
 }
 
@@ -925,7 +923,7 @@ mousepad_util_search (GtkTextBuffer       *buffer,
   /* store the initial iters in marks */
   mark_start = gtk_text_buffer_create_mark (buffer, NULL, &start, TRUE);
   mark_iter  = gtk_text_buffer_create_mark (buffer, NULL, &iter, TRUE);
-  mark_end   = gtk_text_buffer_create_mark (buffer, NULL, &end, TRUE);
+  mark_end   = gtk_text_buffer_create_mark (buffer, NULL, &end, FALSE);
 
   /* some to make the code easier to read */
   search_backwards = ((flags & MOUSEPAD_SEARCH_FLAGS_DIR_BACKWARD) != 0);
@@ -942,6 +940,9 @@ mousepad_util_search (GtkTextBuffer       *buffer,
 
       /* set the new search string */
       string = reversed;
+
+      /* start before the selection */
+      gtk_text_iter_backward_char (&iter);
     }
 
   do
