@@ -20,10 +20,16 @@
 #include <mousepad/mousepad-util.h>
 #include <mousepad/mousepad-view.h>
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+#include <gtksourceview/gtksource.h>
+#else
 #include <gtksourceview/gtksourcebuffer.h>
 #include <gtksourceview/gtksourceview.h>
 #include <gtksourceview/gtksourcestylescheme.h>
 #include <gtksourceview/gtksourcestyleschememanager.h>
+#endif
+
+#include <xfconf/xfconf.h>
 
 /* GTK+ 3 removed textview->im_context which is used for multi-selection and
  * nobody has re-written multi-selection feature to not use this field
@@ -35,7 +41,7 @@
 
 
 
-#define MOUSEPAD_VIEW_DEFAULT_FONT "Monospace"
+#define MOUSEPAD_VIEW_DEFAULT_FONT "Monospace 10"
 #define mousepad_view_get_buffer(view) (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)))
 
 
@@ -249,18 +255,30 @@ mousepad_view_buffer_changed (MousepadView *view,
                               gpointer      user_data)
 {
   GtkSourceBuffer *buffer;
-
   buffer = (GtkSourceBuffer*) gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
+
   if (GTK_SOURCE_IS_BUFFER (buffer))
     {
       GtkSourceStyleSchemeManager *manager;
       GtkSourceStyleScheme        *scheme;
+      gboolean enable_highlight = TRUE;
 
       manager = gtk_source_style_scheme_manager_get_default ();
       scheme = gtk_source_style_scheme_manager_get_scheme (manager,
         view->color_scheme ? view->color_scheme : "");
-      gtk_source_buffer_set_style_scheme (buffer, scheme);
 
+#ifdef GTK_SOURCE_CHECK_VERSION
+#if GTK_SOURCE_CHECK_VERSION (3, 21, 0)
+      if (!GTK_SOURCE_IS_STYLE_SCHEME (scheme))
+      {
+        scheme = gtk_source_style_scheme_manager_get_scheme (manager, "classic");
+        enable_highlight = FALSE;
+      }
+#endif
+#endif
+
+      gtk_source_buffer_set_style_scheme (buffer, scheme);
+      gtk_source_buffer_set_highlight_syntax (buffer, enable_highlight);
       gtk_source_buffer_set_highlight_matching_brackets (buffer, view->match_braces);
     }
 }
@@ -2686,8 +2704,18 @@ mousepad_view_update_font (MousepadView *view)
 
   if (use_default)
     {
+      XfconfChannel *channel = xfconf_channel_get ("xsettings");
+      gchar *font = xfconf_channel_get_string (channel, "/Gtk/MonospaceFontName", NULL);
       PangoFontDescription *font_desc;
-      font_desc = pango_font_description_from_string (MOUSEPAD_VIEW_DEFAULT_FONT);
+
+      if (G_LIKELY (font != NULL))
+        {
+          font_desc = pango_font_description_from_string (font);
+          g_free (font);
+        }
+      else
+          font_desc = pango_font_description_from_string (MOUSEPAD_VIEW_DEFAULT_FONT);
+
       mousepad_view_override_font (view, font_desc);
       pango_font_description_free (font_desc);
     }
